@@ -1,16 +1,18 @@
 import os
 from pyramid import testing
 from webtest import TestApp
-from cms import main, utils
+from cms import main
 from cms.tests.utils import BaseTestCase, RepoHelper
 
 
 class NotifyTestCase(BaseTestCase):
 
     def setUp(self):
-        self.repo_path = os.path.join(os.getcwd(), '.test_repo')
+        self.repo_path = os.path.join(
+            os.getcwd(), '.test_repos', self.id())
 
-        self.repo_path_remote = os.path.join(os.getcwd(), '.test_remote_repo')
+        self.repo_path_remote = os.path.join(
+            os.getcwd(), '.test_remote_repos', self.id())
         self.remote_repo = RepoHelper.create(self.repo_path_remote)
 
         self.config = testing.setUp()
@@ -23,11 +25,7 @@ class NotifyTestCase(BaseTestCase):
 
     def tearDown(self):
         self.remote_repo.destroy()
-        try:
-            repo = RepoHelper.create(self.repo_path)
-            repo.destroy()
-        except:
-            pass
+        RepoHelper.read(self.repo_path).destroy()
         testing.tearDown()
 
     def test_fastforward(self):
@@ -43,8 +41,6 @@ class NotifyTestCase(BaseTestCase):
         # this should trigger a fastforward
         self.app.post('/api/notify/', status=200)
 
-        utils.WORKSPACE_CACHE = {}
-
         resp = self.app.get('/api/pages.json', status=200)
         self.assertEquals(len(resp.json), 2)
         resp = self.app.get('/api/categories.json', status=200)
