@@ -1,7 +1,6 @@
 import os
 from unittest import TestCase
 
-from cms.utils import get_workspace
 from cms.tests.utils import RepoHelper
 
 
@@ -10,10 +9,10 @@ class TestUtils(TestCase):
     def test_get_worspace_caching(self):
 
         repo_helper = RepoHelper.create(
-            os.path.join(os.getcwd(), '.workspace_test'))
+            os.path.join(os.getcwd(), '.workspace_test', self.id()))
         self.addCleanup(repo_helper.destroy)
 
-        repo = repo_helper.repo
-        workspace1 = get_workspace(repo)
-        workspace2 = get_workspace(repo)
+        workspace1 = repo_helper.get_workspace()
+        workspace2 = repo_helper.get_workspace()
         self.assertEqual(workspace1, workspace2)
+        self.assertTrue(repo_helper in RepoHelper.WORKSPACE_CACHE.values())
